@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2013  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2012-2014  Kouhei Sutou <kou@clear-code.com>
 # Copyright (C) 2010  Eddie Lau <tatonlto@gmail.com>
 #
 # License: Ruby's or LGPL
@@ -471,6 +471,26 @@ msgstr ""
 msgid "Hello"
 msgstr ""
 
+#: hello.rb:3
+msgid "Hello World"
+msgstr ""
+
+#: hello.rb:2
+msgid "World"
+msgstr "Translated World"
+        PO
+      end
+
+      def test_sort_by_file
+        @msgmerge.run("--update",
+                      "--sort-by-file",
+                      @po_file_path, @pot_file_path)
+        assert_equal(<<-PO, File.read(@po_file_path))
+#{po_header(@pot_formatted_time, @po_formatted_time)}
+#: hello.rb:1
+msgid "Hello"
+msgstr ""
+
 #: hello.rb:2
 msgid "World"
 msgstr "Translated World"
@@ -481,9 +501,9 @@ msgstr ""
         PO
       end
 
-      def test_sort_by_file
+      def test_sort_by_location
         @msgmerge.run("--update",
-                      "--sort-by-file",
+                      "--sort-by-location",
                       @po_file_path, @pot_file_path)
         assert_equal(<<-PO, File.read(@po_file_path))
 #{po_header(@pot_formatted_time, @po_formatted_time)}
@@ -690,5 +710,43 @@ msgstr ""
         PO
       end
     end
+
+    class TestObsoleteEntries < self
+      def pot_content
+        <<-POT
+msgid "World"
+msgstr ""
+        POT
+      end
+
+      def po_content
+        <<-PO
+msgid "Hello!"
+msgstr "Bonjour!"
+        PO
+      end
+
+      def test_default
+        @msgmerge.run("--update",
+                      @po_file_path, @pot_file_path)
+        assert_equal(<<-PO, File.read(@po_file_path))
+msgid "World"
+msgstr ""
+
+#~ msgid "Hello!"
+#~ msgstr "Bonjour!"
+        PO
+      end
+
+      def test_no_obsolete_entries
+        @msgmerge.run("--update",
+                      "--no-obsolete-entries",
+                      @po_file_path, @pot_file_path)
+        assert_equal(<<-PO, File.read(@po_file_path))
+msgid "World"
+msgstr ""
+        PO
+      end
+    end
   end
 end
